@@ -190,6 +190,9 @@ classdef calendarDuration
           if (! (isnumeric (X) && ismatrix (X)))
             error ("calendarDuration: X must be a numeric matrix.");
           endif
+          if (! isreal (X))
+            error ("calendarDuration: X must be real.");
+          endif
           if (size (X, 2) == 3)
             tmp = X(:);
             tmp(isnan(tmp)) = 0;
@@ -222,6 +225,9 @@ classdef calendarDuration
           if (! (isnumeric (Y) && isnumeric (M) && isnumeric (D)))
             error ("calendarDuration: Y, MO, and D must be a numeric arrays.");
           endif
+          if (! (isreal (Y) && isreal (M) && isreal (D)))
+            error ("calendarDuration: Y, MO, and D must be real.");
+          endif
           ## Expand as necessary
           if (! isscalar (Y) || ! isscalar (M) || ! isscalar (D))
             [err, Y, M, D] = common_size (Y, M, D);
@@ -244,6 +250,9 @@ classdef calendarDuration
           if (! (isnumeric (Y) && isnumeric (M) && isnumeric (D)))
             error ("calendarDuration: Y, MO, and D must be a numeric arrays.");
           endif
+          if (! (isreal (Y) && isreal (M) && isreal (D)))
+            error ("calendarDuration: Y, MO, and D must be real.");
+          endif
           if (! isa (T, "duration"))
             error ("calendarDuration: T must be a duration array.");
           endif
@@ -269,6 +278,10 @@ classdef calendarDuration
         ## this = calendarDuration (Y, M, D, H, MI, S)
         case 6
           [Y, M, D, H, MI, S] = args{:};
+          if (! (isreal (Y) && isreal (M) && isreal (D) &&
+                 isreal (H) && isreal (MI) && isreal (S)))
+            error ("calendarDuration: numeric input data must be real.");
+          endif
           ## Expand as necessary
           if (! isscalar (Y) || ! isscalar (M) || ! isscalar (D) ||
               ! isscalar (H) || ! isscalar (MI) || ! isscalar (S))
@@ -292,8 +305,8 @@ classdef calendarDuration
       endswitch
 
       ## Construction
-      this.Months = Y * 12 + M;
-      this.Days = D;
+      this.Months = double (Y) * 12 + double (M);
+      this.Days = double (D);
       this.Time = T;
 
       ## Broadcast NaNs
@@ -332,11 +345,35 @@ classdef calendarDuration
               els{end+1} = sprintf ('%dy', years);
             endif
             if (months != 0)
-              els{end+1} = sprintf ('%dmo', months);
+              ## Check Format contains 'q' to split between quarters and months
+              if (! isempty (strfind (calDur.Format, 'q')))
+                quarters = fix (months / 3);
+                months = rem (months, 3);
+                if (quarters != 0)
+                  els{end+1} = sprintf ('%dq', quarters);
+                endif
+                if (months != 0)
+                  els{end+1} = sprintf ('%dmo', months);
+                endif
+              else
+                els{end+1} = sprintf ('%dmo', months);
+              endif
             endif
           else
             if (calDur.Months != 0)
-              els{end+1} = sprintf ('%dmo', calDur.Months);
+              ## Check Format contains 'q' to split between quarters and months
+              if (! isempty (strfind (calDur.Format, 'q')))
+                quarters = fix (calDur.Months / 3);
+                months = rem (calDur.Months, 3);
+                if (quarters != 0)
+                  els{end+1} = sprintf ('%dq', quarters);
+                endif
+                if (months != 0)
+                  els{end+1} = sprintf ('%dmo', months);
+                endif
+              else
+                els{end+1} = sprintf ('%dmo', calDur.Months);
+              endif
             endif
           endif
           if (calDur.Days != 0)
@@ -1105,12 +1142,24 @@ classdef calendarDuration
 ################################################################################
 ##                             Available Methods                              ##
 ##                                                                            ##
-## 'subsref'          'subsasgn'                                              ##
+## 'end'              'subsref'          'subsasgn'                           ##
 ##                                                                            ##
 ################################################################################
 
   methods (Hidden)
 
+    ## Overloaded end keyword
+    function last_index = end (this, end_dim, ndim_obj)
+      lastdim = ndims (this);
+      if (end_dim == ndim_obj && ndim_obj == 1)
+        last_index = prod (size (this));
+      elseif (end_dim == ndim_obj && end_dim < lastdim)
+        last_index = prod (size (this)(end_dim:lastdim));
+      else
+        last_index = size (this, end_dim);
+      endif
+    endfunction
+
     ## Class specific subscripted reference
     function varargout = subsref (this, s)
 
